@@ -1,8 +1,12 @@
 package Template::Reverse::Spacer::Numeric;
+
+# ABSTRACT: Insert spaces around Numeric word.
+
 use Any::Moose;
 use namespace::autoclean;
 
-our $VERSION = '0.004';
+our $VERSION = '0.006'; # VERSION
+
 sub Space{
     my $self = shift;
     my $str = shift;
@@ -24,6 +28,11 @@ sub _num{
     $m =~ s/[\.,]$/ $&/;      
     return " $m ";
 }
+
+__PACKAGE__->meta->make_immutable;
+1;
+
+__END__
 =pod
 
 =head1 NAME
@@ -32,15 +41,24 @@ Template::Reverse::Spacer::Numeric - Insert spaces around Numeric word.
 
 =head1 VERSION
 
-0.0004
+version 0.006
 
 =head1 SYNOPSIS
-    
+
     package Template::Reverse::Spacer::Numeric;
     my $num = Template::Reverse::Spacer::Numeric->new;
     $num->Space('1,000dollers'); # '1,000 dollers'
 
+=head1 AUTHOR
+
+HyeonSeung Kim <sng2nara@hanmail.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by HyeonSeung Kim.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-__PACKAGE__->meta->make_immutable;
-1;
