@@ -1,8 +1,12 @@
 package Template::Reverse::Spacer::Punctuation;
+
+# ABSTRACT: Insert spaces around punctuations.
+
 use Any::Moose;
 use namespace::autoclean;
 
-our $VERSION = '0.004';
+our $VERSION = '0.006'; # VERSION
+
 sub Space{
     my $self = shift;
     my $str = shift;
@@ -29,6 +33,11 @@ sub _punc{
     }
 }
 
+
+__PACKAGE__->meta->make_immutable;
+1;
+
+__END__
 =pod
 
 =head1 NAME
@@ -37,15 +46,24 @@ Template::Reverse::Spacer::Punctuation - Insert spaces around punctuations.
 
 =head1 VERSION
 
-0.0004
+version 0.006
 
 =head1 SYNOPSIS
-    
+
     package Template::Reverse::Spacer::Punctuation;
     my $num = Template::Reverse::Spacer::Punctuation->new;
     $num->Space('hello,world!!'); # 'hello , world !!'
 
+=head1 AUTHOR
+
+HyeonSeung Kim <sng2nara@hanmail.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by HyeonSeung Kim.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-__PACKAGE__->meta->make_immutable;
-1;
